@@ -37,7 +37,7 @@ void HistoryInfoWindow::load(QString name, QString group)
     {
         set.setNum(j+1);
         if(group != "Cardio")
-            lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " kg " +
+            lblSet[j]->setText("Set " + set + ": " + list.takeFirst() +" " +
                                 list.takeFirst() + " reps - " + list.takeFirst());
         else
             lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " km on " +
