@@ -126,14 +126,20 @@ void NewExerciseWindow::saveExercise()
         tmpName = name;
         tmpName.replace(" ", "");
         tmpName.append("1.png");
-        dir.rename(pic1,"/home/user/.qexercise/Images/" + name);
+        if(!dir.rename(pic1,"/home/user/.qexercise/Images/" + tmpName))
+        {
+            qDebug() << "pic1 error";
+        }
     }
     if(pic2 != "")
     {
         tmpName = name;
         tmpName.replace(" ", "");
         tmpName.append("2.png");
-        dir.rename(pic2,"/home/user/.qexercise/Images/" + name);
+        if(!dir.rename(pic2,"/home/user/.qexercise/Images/" + tmpName))
+        {
+            qDebug() << "pic2 error";
+        }
     }
 
     QMaemo5InformationBox::information(this, "Exercise saved.",
